﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using ThinkGeo.MapSuite.WebEdition;
using ThinkGeo.MapSuite.Core;
using System.Collections.ObjectModel;
using System.Web.UI.HtmlControls;

namespace MS_OSPFM
{
    public partial class MarkerWithLabel : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                //btnMeasureLine.Attributes.Add("onclick", "activate()");
                //btnNormal.Attributes.Add("onclick", "deactivate()");

                #region Set Map Properties and values
                string sUnit = "Meter";
                Map1.MapBackground.BackgroundBrush = new GeoSolidBrush(GeoColor.FromHtml("#B3C6D4"));
                Map1.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);
                Map1.MapTools.PanZoom.Enabled = false;
                Map1.MapTools.PanZoomBar.Enabled = true;
                Map1.MapUnit = (GeographyUnit)Enum.Parse(typeof(GeographyUnit), sUnit);

                LayerOverlay layerOverLay = new LayerOverlay("OSPFM Layers");
                layerOverLay.IsBaseOverlay = false;
                layerOverLay.ClientCache.CacheId = "OSPFM_Layers";
                layerOverLay.TransitionEffect = TransitionEffect.None;
                layerOverLay.TileType = TileType.SingleTile;
                layerOverLay.Layers.Clear();

                //# end of Map properties
                #endregion

                //15 - Load Access_Point
                ShapeFileFeatureLayer lyr_points_Access_Point = new ShapeFileFeatureLayer(Server.MapPath("~/Data/Access_Points.shp"));
                lyr_points_Access_Point.ZoomLevelSet.ZoomLevel18.DefaultPointStyle = PointStyles.CreateSimplePointStyle(PointSymbolType.Square, GeoColor.SimpleColors.Blue, 15f);
                lyr_points_Access_Point.ZoomLevelSet.ZoomLevel18.DefaultTextStyle = TextStyles.City1("TYPE_NAME");
                lyr_points_Access_Point.ZoomLevelSet.ZoomLevel18.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                lyr_points_Access_Point.DrawingMarginPercentage = 50;

                lyr_points_Access_Point.Close();

                //3 - Load Fiber_Security_Aerial.shp
                ShapeFileFeatureLayer lyr_lines_Buried_Cable = new ShapeFileFeatureLayer(Server.MapPath("~/Data/Fiber_Security_Aerial.shp"));
                lyr_lines_Buried_Cable.ZoomLevelSet.ZoomLevel01.DefaultLineStyle = LineStyles.CreateSimpleLineStyle(GeoColor.StandardColors.Crimson, 2f, true);
                lyr_lines_Buried_Cable.ZoomLevelSet.ZoomLevel01.DefaultTextStyle = TextStyles.Pipeline1("LABEL");
                lyr_lines_Buried_Cable.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
                lyr_lines_Buried_Cable.DrawingMarginPercentage = 50;

                InMemoryFeatureLayer rectLayer = new InMemoryFeatureLayer();
                rectLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(30, GeoColor.StandardColors.DarkBlue);
                rectLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

                Proj4Projection proj4_points_Access_Points = new Proj4Projection();
                proj4_points_Access_Points.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4_points_Access_Points.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                lyr_points_Access_Point.FeatureSource.Projection = proj4_points_Access_Points;

                Proj4Projection proj4_lines_Buried_Cable = new Proj4Projection();
                proj4_lines_Buried_Cable.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4_lines_Buried_Cable.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                lyr_lines_Buried_Cable.FeatureSource.Projection = proj4_lines_Buried_Cable;

                Proj4Projection proj4_rectLayer = new Proj4Projection();
                proj4_rectLayer.InternalProjectionParametersString = Proj4Projection.GetEpsgParametersString(4326);
                proj4_rectLayer.ExternalProjectionParametersString = Proj4Projection.GetGoogleMapParametersString();
                rectLayer.FeatureSource.Projection = proj4_rectLayer;

                layerOverLay.Layers.Add("Lyr_Access_Point", lyr_points_Access_Point);
                layerOverLay.Layers.Add("Lyr_Buried_Cable", lyr_lines_Buried_Cable);
                layerOverLay.Layers.Add("rectLayer", rectLayer);

                VirtualEarthOverlay ve = new VirtualEarthOverlay("VirtualEarth Map");
                ve.VirtualEarthMapType = VirtualEarthMapType.Birdseye;

                Map1.CustomOverlays.Clear();
                Map1.CustomOverlays.Add(layerOverLay);
                Map1.CustomOverlays.Add(ve);

            }
        }

        protected void Map1_TrackShapeFinished(object sender, EventArgs e)
        {
            RectangleShape rectangle;

            if (Map1.EditOverlay.Features.Count != 0)
            {
                rectangle = Map1.EditOverlay.Features[0].GetBoundingBox();
                ViewState["rectangle"] = rectangle;
            }
            else
            {
                rectangle = (RectangleShape)ViewState["rectangle"];
            }

            ShapeFileFeatureLayer Lyr_Buried_Cable = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[0]).Layers["Lyr_Buried_Cable"];
            ShapeFileFeatureLayer Lyr_Access_Point = (ShapeFileFeatureLayer)((LayerOverlay)Map1.CustomOverlays[0]).Layers["Lyr_Access_Point"];
            InMemoryFeatureLayer recLayer = (InMemoryFeatureLayer)((LayerOverlay)Map1.CustomOverlays[0]).Layers["rectLayer"];

            Lyr_Buried_Cable.Open();
            Lyr_Access_Point.Open();
            recLayer.Open();
            Collection<Feature> lineFeatures = Lyr_Buried_Cable.QueryTools.GetFeaturesIntersecting(rectangle, ReturningColumnsType.AllColumns);
            Collection<Feature> pointFeatures = Lyr_Access_Point.QueryTools.GetFeaturesIntersecting(rectangle, ReturningColumnsType.AllColumns);
            recLayer.InternalFeatures.Clear();
            recLayer.InternalFeatures.Add(new Feature(rectangle));

            Lyr_Buried_Cable.Close();
            Lyr_Access_Point.Close();
            recLayer.Close();

            AddList(lineFeatures);
            AddList(pointFeatures);

            Map1.EditOverlay.Features.Clear();
        }

        void AddList(Collection<Feature> features)
        {
            if (features.Count != 0)
            {
                WellKnownType featureType = features[0].GetWellKnownType();
                string shapeTypeString = (featureType == WellKnownType.Point ? "Points" : "Lines");
                string colName = shapeTypeString == "Points" ? "Type_Name" : "Name";

                System.Web.UI.WebControls.Label label = new System.Web.UI.WebControls.Label();
                label.Text = shapeTypeString + "<br/>";
                label.Font.Size = 10;
                panel.Controls.Add(label);
                foreach (Feature feature in features)
                {
                    LiteralControl br = new LiteralControl("<br/>");
                    HtmlAnchor anchor = new HtmlAnchor();
                    anchor.InnerHtml = feature.ColumnValues[colName];
                    anchor.HRef = "#";
                    anchor.Attributes.Add("wkt", feature.GetWellKnownText());
                    anchor.Attributes.Add("onmouseover", "linkOver(this)");
                    anchor.Attributes.Add("onmouseout", "linkOut()");

                    panel.Controls.Add(anchor);
                    panel.Controls.Add(br);
                }
            }
        }

    }
}
